@@ -1,6 +1,9 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
+#![allow(clippy::missing_safety_doc)]
+#![allow(clippy::non_send_fields_in_send_ty)]
+#![doc = include_str!("../README.md")]
 
 pub use ffi;
 pub use glib;
@@ -31,6 +34,4 @@ pub use crate::auto::*;
 pub mod prelude {
     #[doc(hidden)]
     pub use gst_sdp::prelude::*;
-
-    pub use crate::auto::traits::*;
 }
